@@ -1,5 +1,5 @@
 #!/bin/sh -f
-# $Id: pv.sh 8104 2007-07-05 10:41:52Z till $
+# $Id: pv.sh 11351 2010-06-03 00:32:07Z hintak $
 #
 # pv - preview a specified page of a dvi file in a Ghostscript window
 # usage: pv page file
@@ -38,5 +38,5 @@ tmpfile=`mktemp -t ${FILE}XXXXXXXXXX` || exit 1
 trap "rm -rf $tmpfile" 0 1 2 15
 #dvips -D$RESOLUTION -p $PAGE -n 1 "$FILE" "$@" -o $tmpfile
 dvips -p $PAGE -n 1 "$FILE" "$@" -o $tmpfile
-$GS_EXECUTABLE $tmpfile
+$GS_EXECUTABLE -P- -dSAFER $tmpfile
 exit 0
